==> custom_pages-v1.12.7.zip: custom_pages/messages/hu/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '{templateName} elem <strong>hozzáadása</strong>',
    '<strong>Custom</strong> Pages' => '<strong>Egyedi</strong> oldalak',
    '<strong>Edit</strong> snippet' => '<strong>Oldalmenük</strong> szerkesztése',
    'Add' => 'Hozzáadás',
    'Add a file icon before the title' => 'Fájlikon hozzáadása a cím előtt',
    'Adds plain HTML content to your site.' => 'HTML tartalom hozzáadása az oldaladhoz.',
    'Advanced' => 'Haladó',
    'Allows the user to manage custom pages.' => 'Lehetővé teszi a felhasználó számára az egyéni oldalak kezelését.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Lehetővé teszi oldalak (markdown, iframe vagy linkek) hozzáadását a közösségi navigációhoz',
    'Allows you to add content in MarkDown syntax.' => 'Lehetővé teszi tartalom hozzáadását MarkDown szintaxisban.',
    'Alternate text' => 'Alternatív szöveg',
    'Always' => 'Mindig',
    'Always make a backup of your view files outside of your production environment!' => 'A gyártási környezeten kívül mindig készíts biztonsági mentést a nézet fájlokról!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Ha az engedélyezett sablon mezőt üresen hagyod, akkor az összes tároló-sablon engedélyezve lesz ehhez a tárolóhoz.',
    'Back' => 'Vissza',
    'Back to dashboard' => 'Vissza az áttekintésre',
    'Back to overview' => 'Vissza az áttekintésre',
    'Back to space' => 'Vissza a közösséghez',
    'Can manage custom pages' => 'Kezelheti az egyedi oldalakat',
    'Category' => 'Kategória',
    'Configuration' => 'Konfiguráció',
    'Content' => 'Tartalom',
    'Create' => 'Létrehozás',
    'Css Class' => 'CSS osztály',
    'Custom' => 'Egyedi',
    'Custom Pages' => 'Egyedi oldalak',
    'Custom pages' => 'Egyedi oldalak',
    'Dashboard' => 'Áttekintés',
    'Default' => 'Alapértelmezett',
    'Default Content' => 'Alapértelmezett tartalom',
    'Delete' => 'Törlés',
    'Edit' => 'Szerkesztés',
    'Edit Page' => 'Oldal szerkesztése',
    'Empty' => 'Üres',
    'File' => 'Fájl',
    'Footer menu' => 'Lábléc menü',
    'General' => 'Általános',
    'Html' => 'HTML',
    'ID' => 'Azonosító',
    'Icon' => 'Ikon',
    'Iframe' => 'Beágyazott (iFrame)',
    'Insert' => 'Beillesztés',
    'Invalid request data!' => 'Érvénytelen kért adat!',
    'Invalid template selection!' => 'Érvénytelen sablonválasztás!',
    'Invalid type selection' => 'Érvénytelen típusválasztás',
    'Invalid view file selection!' => 'Érvénytelen megtekintési fájl választás!',
    'Link' => 'Hivatkozás',
    'MarkDown' => 'Legördülő menü',
    'Menu settings' => 'Menübeállítások',
    'Navigation' => 'Navigáció',
    'On this page you can configure general settings of your custom pages.' => 'Ezen az oldalon éred el egyedi oldalaid általános beállításait.',
    'Overview' => 'Áttekintés',
    'PHP' => 'PHP',
    'Page' => 'Oldal',
    'Pages' => 'Oldalak',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Kérjük, válasszon a következő tartalomtípusok egyikéből. A tartalom típusa határozza meg, hogy a tartalma hogyan ágyazódik be a webhelyére.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Ne feledd, hogy a php-alapú oldalak biztonsági réseknek vannak kitéve, különösen a felhasználói bevitel kezelésekor. További információért, ld. <a href="%7Burl%7D">Yii biztonsági tanácsai</a>.',
    'Public' => 'Nyilvános',
    'Reset' => 'Visszaállítás',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Csak a látható szöveges csomópontoknál válassza ezt a beállítást. Törölje a jelet arról az esetről, ha ezt az elemet például HTML attribútum értékként használják.',
    'Settings' => 'Beállítások',
    'Show additional file information (size)' => 'Mutassa a további fájlinformációkat (méret)',
    'Snippet' => 'Kódrészlet (snippet)',
    'Snippets' => 'Kódrészletek (snippet)',
    'Sort Order' => 'Rendezési sorrend',
    'Source' => 'Forrás',
    'Space' => 'Közösség',
    'Space Members only' => 'Csak Space Felhasználó',
    'Space Navigation' => 'Space Navigáció',
    'Spaces' => 'Közösségek',
    'Stream' => 'Hírfolyam',
    'Stream options' => 'Streamelési lehetőségek',
    'Style' => 'Stílus',
    'Style Class' => 'Stílus osztály',
    'Submit' => 'Küldés',
    'Target Url' => 'Cél hivatkozás (URL)',
    'Template' => 'Sablon',
    'Template Layout' => 'Sablon elrendezés',
    'Templates' => 'Sablonok',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'A sablonok segítségével kombinálható oldaltöredékek definiálhatók az inline szerkesztési funkciókkal.',
    'This container does not allow any further items!' => 'Ez a tároló nem engedélyez további elemeket!',
    'Title' => 'Cím',
    'Top Navigation' => 'Felső navigáció',
    'Topics' => 'Témák',
    'Type' => 'Típus',
    'Upload image' => 'Kép feltöltése',
    'User Account Menu (Settings)' => 'Felhasználói menü (Beállítások)',
    'Visibility' => 'Láthatóság',
    'Will embed the result of a given url as an iframe element.' => 'Beágyazza egy adott url eredményét iframe elemként.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Átirányítja a kéréseket egy adott (relatív vagy abszolút) URL-re.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'A PHP-alapú oldalakkal egyedi oldalakat hozhatsz létre a fájlrendszereden belüli nézetfájlok segítségével. További információkért tekintsd meg a modul konfigurációját.',
    'Without adding to navigation (Direct link)' => 'A navigációhoz való hozzáadás nélkül (közvetlen link)',
    'You are not allowed to delete default content!' => 'Nem vagy jogosult az alapértelmezett tartalom törlésére!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Authors' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/hu/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '{templateName} elem <strong>hozzáadása</strong>',
    '<strong>Custom</strong> Pages' => '<strong>Egyedi</strong> oldalak',
    '<strong>Edit</strong> snippet' => '<strong>Oldalmenük</strong> szerkesztése',
    'Add' => 'Hozzáadás',
    'Add a file icon before the title' => 'Fájlikon hozzáadása a cím előtt',
    'Adds plain HTML content to your site.' => 'HTML tartalom hozzáadása az oldaladhoz.',
    'Advanced' => 'Haladó',
    'Allows the user to manage custom pages.' => 'Lehetővé teszi a felhasználó számára az egyéni oldalak kezelését.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Lehetővé teszi oldalak (markdown, iframe vagy linkek) hozzáadását a közösségi navigációhoz',
    'Allows you to add content in MarkDown syntax.' => 'Lehetővé teszi tartalom hozzáadását MarkDown szintaxisban.',
    'Alternate text' => 'Alternatív szöveg',
    'Always' => 'Mindig',
    'Always make a backup of your view files outside of your production environment!' => 'A gyártási környezeten kívül mindig készíts biztonsági mentést a nézet fájlokról!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Ha az engedélyezett sablon mezőt üresen hagyod, akkor az összes tároló-sablon engedélyezve lesz ehhez a tárolóhoz.',
    'Back' => 'Vissza',
    'Back to dashboard' => 'Vissza az áttekintésre',
    'Back to overview' => 'Vissza az áttekintésre',
    'Back to space' => 'Vissza a közösséghez',
    'Can manage custom pages' => 'Kezelheti az egyedi oldalakat',
    'Category' => 'Kategória',
    'Configuration' => 'Konfiguráció',
    'Content' => 'Tartalom',
    'Create' => 'Létrehozás',
    'Css Class' => 'CSS osztály',
    'Custom' => 'Egyedi',
    'Custom Pages' => 'Egyedi oldalak',
    'Custom pages' => 'Egyedi oldalak',
    'Dashboard' => 'Áttekintés',
    'Default' => 'Alapértelmezett',
    'Default Content' => 'Alapértelmezett tartalom',
    'Delete' => 'Törlés',
    'Edit' => 'Szerkesztés',
    'Edit Page' => 'Oldal szerkesztése',
    'Empty' => 'Üres',
    'File' => 'Fájl',
    'Footer menu' => 'Lábléc menü',
    'General' => 'Általános',
    'Html' => 'HTML',
    'ID' => 'Azonosító',
    'Icon' => 'Ikon',
    'Iframe' => 'Beágyazott (iFrame)',
    'Insert' => 'Beillesztés',
    'Invalid request data!' => 'Érvénytelen kért adat!',
    'Invalid template selection!' => 'Érvénytelen sablonválasztás!',
    'Invalid type selection' => 'Érvénytelen típusválasztás',
    'Invalid view file selection!' => 'Érvénytelen megtekintési fájl választás!',
    'Link' => 'Hivatkozás',
    'MarkDown' => 'Legördülő menü',
    'Menu settings' => 'Menübeállítások',
    'Navigation' => 'Navigáció',
    'On this page you can configure general settings of your custom pages.' => 'Ezen az oldalon éred el egyedi oldalaid általános beállításait.',
    'Overview' => 'Áttekintés',
    'PHP' => 'PHP',
    'Page' => 'Oldal',
    'Pages' => 'Oldalak',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Kérjük, válasszon a következő tartalomtípusok egyikéből. A tartalom típusa határozza meg, hogy a tartalma hogyan ágyazódik be a webhelyére.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Ne feledd, hogy a php-alapú oldalak biztonsági réseknek vannak kitéve, különösen a felhasználói bevitel kezelésekor. További információért, ld. <a href="%7Burl%7D">Yii biztonsági tanácsai</a>.',
    'Public' => 'Nyilvános',
    'Reset' => 'Visszaállítás',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Csak a látható szöveges csomópontoknál válassza ezt a beállítást. Törölje a jelet arról az esetről, ha ezt az elemet például HTML attribútum értékként használják.',
    'Settings' => 'Beállítások',
    'Show additional file information (size)' => 'Mutassa a további fájlinformációkat (méret)',
    'Snippet' => 'Kódrészlet (snippet)',
    'Snippets' => 'Kódrészletek (snippet)',
    'Sort Order' => 'Rendezési sorrend',
    'Source' => 'Forrás',
    'Space' => 'Közösség',
    'Space Members only' => 'Csak Space Felhasználó',
    'Space Navigation' => 'Space Navigáció',
    'Spaces' => 'Közösségek',
    'Stream' => 'Hírfolyam',
    'Stream options' => 'Streamelési lehetőségek',
    'Style' => 'Stílus',
    'Style Class' => 'Stílus osztály',
    'Submit' => 'Küldés',
    'Target Url' => 'Cél hivatkozás (URL)',
    'Template' => 'Sablon',
    'Template Layout' => 'Sablon elrendezés',
    'Templates' => 'Sablonok',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'A sablonok segítségével kombinálható oldaltöredékek definiálhatók az inline szerkesztési funkciókkal.',
    'This container does not allow any further items!' => 'Ez a tároló nem engedélyez további elemeket!',
    'Title' => 'Cím',
    'Top Navigation' => 'Felső navigáció',
    'Topics' => 'Témák',
    'Type' => 'Típus',
    'Upload image' => 'Kép feltöltése',
    'User Account Menu (Settings)' => 'Felhasználói menü (Beállítások)',
    'Visibility' => 'Láthatóság',
    'Will embed the result of a given url as an iframe element.' => 'Beágyazza egy adott url eredményét iframe elemként.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Átirányítja a kéréseket egy adott (relatív vagy abszolút) URL-re.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'A PHP-alapú oldalakkal egyedi oldalakat hozhatsz létre a fájlrendszereden belüli nézetfájlok segítségével. További információkért tekintsd meg a modul konfigurációját.',
    'Without adding to navigation (Direct link)' => 'A navigációhoz való hozzáadás nélkül (közvetlen link)',
    'You are not allowed to delete default content!' => 'Nem vagy jogosult az alapértelmezett tartalom törlésére!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
